package ch.zhaw.projekt2.turnierverwaltung.main.gameScheduleView;

import ch.zhaw.projekt2.turnierverwaltung.*;
import javafx.beans.value.ObservableValue;
import javafx.event.Event;
import javafx.fxml.FXML;
import javafx.scene.control.ChoiceBox;
import javafx.scene.control.Label;
import javafx.scene.control.TextField;
import javafx.scene.layout.Pane;
import javafx.scene.layout.VBox;

/**
 * Class GameController in Charge of the Controller Element of the Schedule view.
 */
public class GameController extends FXController{

    private GameDecorator gameDecorator;

    @FXML
    private VBox mainVBox;

    @FXML
    private Label participantNameOne;

    @FXML
    private Label participantNameTwo;

    @FXML
    private ChoiceBox<Place> placesChoiceBox;

    @FXML
    private TextField pointsTeamOne;

    @FXML
    private TextField pointsTeamTwo;

    @FXML

    private Label locationLabel;

    @Override
    public void shareGUIElementWithLanguageConfigurator() {
        getLanguageConfigurator().recieveLabel(locationLabel);
    }

    @FXML
    void saveGameResult() {
        gameDecorator.saveGameResult(pointsTeamOne.getText(), pointsTeamTwo.getText());
    }


    private void saveGamePlace(Place newPlace) {
        gameDecorator.saveGamePlace(newPlace);
    }

    public double getGameBoxHeight(){
        return mainVBox.getPrefHeight();
    }

    @Override
    public void loadContent() {
        getLanguageConfigurator().translateGUI();
        participantNameOne.setText(gameDecorator.getParticipantOne());
        participantNameTwo.setText(gameDecorator.getParticipantTwo());
        pointsTeamOne.setText(String.valueOf(gameDecorator.getPoints1()));
        pointsTeamTwo.setText(String.valueOf(gameDecorator.getPoints2()));
        placesChoiceBox.setItems(getTournamentDecorator().getTournament().getPlaces());
        placesChoiceBox.setValue(gameDecorator.getPlace());
    }

    public void refreshParticipants(){
        gameDecorator.refreshParticipants();
    }

    public void addListener(GameDecorator gameDecorator){
        gameDecorator.addListener(new IsObserver() {
            @Override
            public void update() {
                refreshParticipants();
                loadContent();
            }
        });
    }


    public void setup(TournamentDecorator tournamentDecorator, FileIO fileIO, FactoryDecorator factoryDecorator, Pane pane, GameDecorator gameDecorator,LanguageConfigurator languageConfigurator) {
        setTournamentDecorator(tournamentDecorator);
        this.gameDecorator = gameDecorator;
        setup(languageConfigurator);
        placesChoiceBox.getSelectionModel().selectedItemProperty().addListener((ObservableValue<? extends Place> observable, Place oldValue, Place newValue) -> saveGamePlace(newValue == null ? oldValue : newValue));
    }

}